Readable

Trait Readable 

pub trait Readable: RegisterSpec {
    type Reader: From<R<Self>> + Deref<Target = R<Self>>;
}
Trait implemented by readable registers to enable the read method.

Registers marked with Writable can be also modify’ed.

Required Associated Types

type Reader: From<R<Self>> + Deref<Target = R<Self>>

Result from a call to read and argument to modify.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Readable for ACC_ACR_SPEC

read() method returns acc_acr::R reader structure

Source

impl Readable for ACC_IMR_SPEC

read() method returns acc_imr::R reader structure

Source

impl Readable for ACC_ISR_SPEC

read() method returns acc_isr::R reader structure

Source

impl Readable for ACC_MR_SPEC

read() method returns acc_mr::R reader structure

Source

impl Readable for ACC_WPMR_SPEC

read() method returns acc_wpmr::R reader structure

Source

impl Readable for ACC_WPSR_SPEC

read() method returns acc_wpsr::R reader structure

Source

impl Readable for ACTLR_SPEC

read() method returns actlr::R reader structure

Source

impl Readable for AES_AADLENR_SPEC

read() method returns aes_aadlenr::R reader structure

Source

impl Readable for AES_CLENR_SPEC

read() method returns aes_clenr::R reader structure

Source

impl Readable for AES_CTRR_SPEC

read() method returns aes_ctrr::R reader structure

Source

impl Readable for AES_GCMHR_SPEC

read() method returns aes_gcmhr::R reader structure

Source

impl Readable for AES_GHASHR_SPEC

read() method returns aes_ghashr::R reader structure

Source

impl Readable for AES_IMR_SPEC

read() method returns aes_imr::R reader structure

Source

impl Readable for AES_ISR_SPEC

read() method returns aes_isr::R reader structure

Source

impl Readable for AES_MR_SPEC

read() method returns aes_mr::R reader structure

Source

impl Readable for AES_ODATAR_SPEC

read() method returns aes_odatar::R reader structure

Source

impl Readable for AES_TAGR_SPEC

read() method returns aes_tagr::R reader structure

Source

impl Readable for AFEC_ACR_SPEC

read() method returns afec_acr::R reader structure

Source

impl Readable for AFEC_CDR_SPEC

read() method returns afec_cdr::R reader structure

Source

impl Readable for AFEC_CECR_SPEC

read() method returns afec_cecr::R reader structure

Source

impl Readable for AFEC_CGR_SPEC

read() method returns afec_cgr::R reader structure

Source

impl Readable for AFEC_CHSR_SPEC

read() method returns afec_chsr::R reader structure

Source

impl Readable for AFEC_COCR_SPEC

read() method returns afec_cocr::R reader structure

Source

impl Readable for AFEC_COSR_SPEC

read() method returns afec_cosr::R reader structure

Source

impl Readable for AFEC_CSELR_SPEC

read() method returns afec_cselr::R reader structure

Source

impl Readable for AFEC_CVR_SPEC

read() method returns afec_cvr::R reader structure

Source

impl Readable for AFEC_CWR_SPEC

read() method returns afec_cwr::R reader structure

Source

impl Readable for AFEC_DIFFR_SPEC

read() method returns afec_diffr::R reader structure

Source

impl Readable for AFEC_EMR_SPEC

read() method returns afec_emr::R reader structure

Source

impl Readable for AFEC_IMR_SPEC

read() method returns afec_imr::R reader structure

Source

impl Readable for AFEC_ISR_SPEC

read() method returns afec_isr::R reader structure

Source

impl Readable for AFEC_LCDR_SPEC

read() method returns afec_lcdr::R reader structure

Source

impl Readable for AFEC_MR_SPEC

read() method returns afec_mr::R reader structure

Source

impl Readable for AFEC_OVER_SPEC

read() method returns afec_over::R reader structure

Source

impl Readable for AFEC_SEQ1R_SPEC

read() method returns afec_seq1r::R reader structure

Source

impl Readable for AFEC_SEQ2R_SPEC

read() method returns afec_seq2r::R reader structure

Source

impl Readable for AFEC_SHMR_SPEC

read() method returns afec_shmr::R reader structure

Source

impl Readable for AFEC_TEMPCWR_SPEC

read() method returns afec_tempcwr::R reader structure

Source

impl Readable for AFEC_TEMPMR_SPEC

read() method returns afec_tempmr::R reader structure

Source

impl Readable for AFEC_WPMR_SPEC

read() method returns afec_wpmr::R reader structure

Source

impl Readable for AFEC_WPSR_SPEC

read() method returns afec_wpsr::R reader structure

Source

impl Readable for CALIB_SPEC

read() method returns calib::R reader structure

Source

impl Readable for CCFG_SMCNFCS_SPEC

read() method returns ccfg_smcnfcs::R reader structure

Source

impl Readable for CCFG_SYSIO_SPEC

read() method returns ccfg_sysio::R reader structure

Source

impl Readable for CHIPID_CIDR_SPEC

read() method returns chipid_cidr::R reader structure

Source

impl Readable for CHIPID_EXID_SPEC

read() method returns chipid_exid::R reader structure

Source

impl Readable for CKGR_MCFR_SPEC

read() method returns ckgr_mcfr::R reader structure

Source

impl Readable for CKGR_MOR_SPEC

read() method returns ckgr_mor::R reader structure

Source

impl Readable for CKGR_PLLAR_SPEC

read() method returns ckgr_pllar::R reader structure

Source

impl Readable for CKGR_UCKR_SPEC

read() method returns ckgr_uckr::R reader structure

Source

impl Readable for CSR_SPEC

read() method returns csr::R reader structure

Source

impl Readable for CVR_SPEC

read() method returns cvr::R reader structure

Source

impl Readable for DACC_ACR_SPEC

read() method returns dacc_acr::R reader structure

Source

impl Readable for DACC_CHSR_SPEC

read() method returns dacc_chsr::R reader structure

Source

impl Readable for DACC_IMR_SPEC

read() method returns dacc_imr::R reader structure

Source

impl Readable for DACC_ISR_SPEC

read() method returns dacc_isr::R reader structure

Source

impl Readable for DACC_MR_SPEC

read() method returns dacc_mr::R reader structure

Source

impl Readable for DACC_TRIGR_SPEC

read() method returns dacc_trigr::R reader structure

Source

impl Readable for DACC_WPMR_SPEC

read() method returns dacc_wpmr::R reader structure

Source

impl Readable for DACC_WPSR_SPEC

read() method returns dacc_wpsr::R reader structure

Source

impl Readable for EEFC_FMR_SPEC

read() method returns eefc_fmr::R reader structure

Source

impl Readable for EEFC_FRR_SPEC

read() method returns eefc_frr::R reader structure

Source

impl Readable for EEFC_FSR_SPEC

read() method returns eefc_fsr::R reader structure

Source

impl Readable for EEFC_WPMR_SPEC

read() method returns eefc_wpmr::R reader structure

Source

impl Readable for ICM_CFG_SPEC

read() method returns icm_cfg::R reader structure

Source

impl Readable for ICM_DSCR_SPEC

read() method returns icm_dscr::R reader structure

Source

impl Readable for ICM_HASH_SPEC

read() method returns icm_hash::R reader structure

Source

impl Readable for ICM_IMR_SPEC

read() method returns icm_imr::R reader structure

Source

impl Readable for ICM_ISR_SPEC

read() method returns icm_isr::R reader structure

Source

impl Readable for ICM_SR_SPEC

read() method returns icm_sr::R reader structure

Source

impl Readable for ICM_UASR_SPEC

read() method returns icm_uasr::R reader structure

Source

impl Readable for ICTR_SPEC

read() method returns ictr::R reader structure

Source

impl Readable for ISI_CFG1_SPEC

read() method returns isi_cfg1::R reader structure

Source

impl Readable for ISI_CFG2_SPEC

read() method returns isi_cfg2::R reader structure

Source

impl Readable for ISI_DMA_CHSR_SPEC

read() method returns isi_dma_chsr::R reader structure

Source

impl Readable for ISI_DMA_C_ADDR_SPEC

read() method returns isi_dma_c_addr::R reader structure

Source

impl Readable for ISI_DMA_C_CTRL_SPEC

read() method returns isi_dma_c_ctrl::R reader structure

Source

impl Readable for ISI_DMA_C_DSCR_SPEC

read() method returns isi_dma_c_dscr::R reader structure

Source

impl Readable for ISI_DMA_P_ADDR_SPEC

read() method returns isi_dma_p_addr::R reader structure

Source

impl Readable for ISI_DMA_P_CTRL_SPEC

read() method returns isi_dma_p_ctrl::R reader structure

Source

impl Readable for ISI_DMA_P_DSCR_SPEC

read() method returns isi_dma_p_dscr::R reader structure

Source

impl Readable for ISI_IMR_SPEC

read() method returns isi_imr::R reader structure

Source

impl Readable for ISI_PDECF_SPEC

read() method returns isi_pdecf::R reader structure

Source

impl Readable for ISI_PSIZE_SPEC

read() method returns isi_psize::R reader structure

Source

impl Readable for ISI_R2Y_SET0_SPEC

read() method returns isi_r2y_set0::R reader structure

Source

impl Readable for ISI_R2Y_SET1_SPEC

read() method returns isi_r2y_set1::R reader structure

Source

impl Readable for ISI_R2Y_SET2_SPEC

read() method returns isi_r2y_set2::R reader structure

Source

impl Readable for ISI_SR_SPEC

read() method returns isi_sr::R reader structure

Source

impl Readable for ISI_WPMR_SPEC

read() method returns isi_wpmr::R reader structure

Source

impl Readable for ISI_WPSR_SPEC

read() method returns isi_wpsr::R reader structure

Source

impl Readable for ISI_Y2R_SET0_SPEC

read() method returns isi_y2r_set0::R reader structure

Source

impl Readable for ISI_Y2R_SET1_SPEC

read() method returns isi_y2r_set1::R reader structure

Source

impl Readable for LOCKBIT_WORD0_SPEC

read() method returns lockbit_word0::R reader structure

Source

impl Readable for LOCKBIT_WORD1_SPEC

read() method returns lockbit_word1::R reader structure

Source

impl Readable for LOCKBIT_WORD2_SPEC

read() method returns lockbit_word2::R reader structure

Source

impl Readable for LOCKBIT_WORD3_SPEC

read() method returns lockbit_word3::R reader structure

Source

impl Readable for MATRIX_MCFG_SPEC

read() method returns matrix_mcfg::R reader structure

Source

impl Readable for MATRIX_MRCR_SPEC

read() method returns matrix_mrcr::R reader structure

Source

impl Readable for MATRIX_PRAS_SPEC

read() method returns matrix_pras::R reader structure

Source

impl Readable for MATRIX_PRBS_SPEC

read() method returns matrix_prbs::R reader structure

Source

impl Readable for MATRIX_SCFG_SPEC

read() method returns matrix_scfg::R reader structure

Source

impl Readable for MATRIX_WPMR_SPEC

read() method returns matrix_wpmr::R reader structure

Source

impl Readable for MATRIX_WPSR_SPEC

read() method returns matrix_wpsr::R reader structure

Source

impl Readable for PIO_ABCDSR_SPEC

read() method returns pio_abcdsr::R reader structure

Source

impl Readable for PIO_AIMMR_SPEC

read() method returns pio_aimmr::R reader structure

Source

impl Readable for PIO_DRIVER_SPEC

read() method returns pio_driver::R reader structure

Source

impl Readable for PIO_ELSR_SPEC

read() method returns pio_elsr::R reader structure

Source

impl Readable for PIO_FRLHSR_SPEC

read() method returns pio_frlhsr::R reader structure

Source

impl Readable for PIO_IFSCSR_SPEC

read() method returns pio_ifscsr::R reader structure

Source

impl Readable for PIO_IFSR_SPEC

read() method returns pio_ifsr::R reader structure

Source

impl Readable for PIO_IMR_SPEC

read() method returns pio_imr::R reader structure

Source

impl Readable for PIO_ISR_SPEC

read() method returns pio_isr::R reader structure

Source

impl Readable for PIO_LOCKSR_SPEC

read() method returns pio_locksr::R reader structure

Source

impl Readable for PIO_MDSR_SPEC

read() method returns pio_mdsr::R reader structure

Source

impl Readable for PIO_ODSR_SPEC

read() method returns pio_odsr::R reader structure

Source

impl Readable for PIO_OSR_SPEC

read() method returns pio_osr::R reader structure

Source

impl Readable for PIO_OWSR_SPEC

read() method returns pio_owsr::R reader structure

Source

impl Readable for PIO_PCIMR_SPEC

read() method returns pio_pcimr::R reader structure

Source

impl Readable for PIO_PCISR_SPEC

read() method returns pio_pcisr::R reader structure

Source

impl Readable for PIO_PCMR_SPEC

read() method returns pio_pcmr::R reader structure

Source

impl Readable for PIO_PCRHR_SPEC

read() method returns pio_pcrhr::R reader structure

Source

impl Readable for PIO_PDSR_SPEC

read() method returns pio_pdsr::R reader structure

Source

impl Readable for PIO_PPDSR_SPEC

read() method returns pio_ppdsr::R reader structure

Source

impl Readable for PIO_PSR_SPEC

read() method returns pio_psr::R reader structure

Source

impl Readable for PIO_PUSR_SPEC

read() method returns pio_pusr::R reader structure

Source

impl Readable for PIO_SCDR_SPEC

read() method returns pio_scdr::R reader structure

Source

impl Readable for PIO_SCHMITT_SPEC

read() method returns pio_schmitt::R reader structure

Source

impl Readable for PIO_WPMR_SPEC

read() method returns pio_wpmr::R reader structure

Source

impl Readable for PIO_WPSR_SPEC

read() method returns pio_wpsr::R reader structure

Source

impl Readable for PMC_FSMR_SPEC

read() method returns pmc_fsmr::R reader structure

Source

impl Readable for PMC_FSPR_SPEC

read() method returns pmc_fspr::R reader structure

Source

impl Readable for PMC_IMR_SPEC

read() method returns pmc_imr::R reader structure

Source

impl Readable for PMC_MCKR_SPEC

read() method returns pmc_mckr::R reader structure

Source

impl Readable for PMC_OCR_SPEC

read() method returns pmc_ocr::R reader structure

Source

impl Readable for PMC_PCK_SPEC

read() method returns pmc_pck::R reader structure

Source

impl Readable for PMC_PCR_SPEC

read() method returns pmc_pcr::R reader structure

Source

impl Readable for PMC_PCSR0_SPEC

read() method returns pmc_pcsr0::R reader structure

Source

impl Readable for PMC_PCSR1_SPEC

read() method returns pmc_pcsr1::R reader structure

Source

impl Readable for PMC_PMMR_SPEC

read() method returns pmc_pmmr::R reader structure

Source

impl Readable for PMC_SCSR_SPEC

read() method returns pmc_scsr::R reader structure

Source

impl Readable for PMC_SLPWK_AIPR_SPEC

read() method returns pmc_slpwk_aipr::R reader structure

Source

impl Readable for PMC_SLPWK_ASR0_SPEC

read() method returns pmc_slpwk_asr0::R reader structure

Source

impl Readable for PMC_SLPWK_ASR1_SPEC

read() method returns pmc_slpwk_asr1::R reader structure

Source

impl Readable for PMC_SLPWK_SR0_SPEC

read() method returns pmc_slpwk_sr0::R reader structure

Source

impl Readable for PMC_SLPWK_SR1_SPEC

read() method returns pmc_slpwk_sr1::R reader structure

Source

impl Readable for PMC_SR_SPEC

read() method returns pmc_sr::R reader structure

Source

impl Readable for PMC_USB_SPEC

read() method returns pmc_usb::R reader structure

Source

impl Readable for PMC_WPMR_SPEC

read() method returns pmc_wpmr::R reader structure

Source

impl Readable for PMC_WPSR_SPEC

read() method returns pmc_wpsr::R reader structure

Source

impl Readable for PWM_CCNT_SPEC

read() method returns pwm_ccnt::R reader structure

Source

impl Readable for PWM_CDTY_SPEC

read() method returns pwm_cdty::R reader structure

Source

impl Readable for PWM_CLK_SPEC

read() method returns pwm_clk::R reader structure

Source

impl Readable for PWM_CMPM_SPEC

read() method returns pwm_cmpm::R reader structure

Source

impl Readable for PWM_CMPV_SPEC

read() method returns pwm_cmpv::R reader structure

Source

impl Readable for PWM_CMR_SPEC

read() method returns pwm_cmr::R reader structure

Source

impl Readable for PWM_CPRD_SPEC

read() method returns pwm_cprd::R reader structure

Source

impl Readable for PWM_DT_SPEC

read() method returns pwm_dt::R reader structure

Source

impl Readable for PWM_ELMR_SPEC

read() method returns pwm_elmr::R reader structure

Source

impl Readable for PWM_ETRG1_SPEC

read() method returns pwm_etrg1::R reader structure

Source

impl Readable for PWM_ETRG2_SPEC

read() method returns pwm_etrg2::R reader structure

Source

impl Readable for PWM_FMR_SPEC

read() method returns pwm_fmr::R reader structure

Source

impl Readable for PWM_FPE_SPEC

read() method returns pwm_fpe::R reader structure

Source

impl Readable for PWM_FPV1_SPEC

read() method returns pwm_fpv1::R reader structure

Source

impl Readable for PWM_FPV2_SPEC

read() method returns pwm_fpv2::R reader structure

Source

impl Readable for PWM_FSR_SPEC

read() method returns pwm_fsr::R reader structure

Source

impl Readable for PWM_IMR1_SPEC

read() method returns pwm_imr1::R reader structure

Source

impl Readable for PWM_IMR2_SPEC

read() method returns pwm_imr2::R reader structure

Source

impl Readable for PWM_ISR1_SPEC

read() method returns pwm_isr1::R reader structure

Source

impl Readable for PWM_ISR2_SPEC

read() method returns pwm_isr2::R reader structure

Source

impl Readable for PWM_LEBR1_SPEC

read() method returns pwm_lebr1::R reader structure

Source

impl Readable for PWM_LEBR2_SPEC

read() method returns pwm_lebr2::R reader structure

Source

impl Readable for PWM_OOV_SPEC

read() method returns pwm_oov::R reader structure

Source

impl Readable for PWM_OS_SPEC

read() method returns pwm_os::R reader structure

Source

impl Readable for PWM_SCM_SPEC

read() method returns pwm_scm::R reader structure

Source

impl Readable for PWM_SCUC_SPEC

read() method returns pwm_scuc::R reader structure

Source

impl Readable for PWM_SCUP_SPEC

read() method returns pwm_scup::R reader structure

Source

impl Readable for PWM_SMMR_SPEC

read() method returns pwm_smmr::R reader structure

Source

impl Readable for PWM_SR_SPEC

read() method returns pwm_sr::R reader structure

Source

impl Readable for PWM_SSPR_SPEC

read() method returns pwm_sspr::R reader structure

Source

impl Readable for PWM_WPSR_SPEC

read() method returns pwm_wpsr::R reader structure

Source

impl Readable for QSPI_IAR_SPEC

read() method returns qspi_iar::R reader structure

Source

impl Readable for QSPI_ICR_SPEC

read() method returns qspi_icr::R reader structure

Source

impl Readable for QSPI_IFR_SPEC

read() method returns qspi_ifr::R reader structure

Source

impl Readable for QSPI_IMR_SPEC

read() method returns qspi_imr::R reader structure

Source

impl Readable for QSPI_MR_SPEC

read() method returns qspi_mr::R reader structure

Source

impl Readable for QSPI_RDR_SPEC

read() method returns qspi_rdr::R reader structure

Source

impl Readable for QSPI_SCR_SPEC

read() method returns qspi_scr::R reader structure

Source

impl Readable for QSPI_SMR_SPEC

read() method returns qspi_smr::R reader structure

Source

impl Readable for QSPI_SR_SPEC

read() method returns qspi_sr::R reader structure

Source

impl Readable for QSPI_WPMR_SPEC

read() method returns qspi_wpmr::R reader structure

Source

impl Readable for QSPI_WPSR_SPEC

read() method returns qspi_wpsr::R reader structure

Source

impl Readable for RSTC_MR_SPEC

read() method returns rstc_mr::R reader structure

Source

impl Readable for RSTC_SR_SPEC

read() method returns rstc_sr::R reader structure

Source

impl Readable for RSWDT_MR_SPEC

read() method returns rswdt_mr::R reader structure

Source

impl Readable for RSWDT_SR_SPEC

read() method returns rswdt_sr::R reader structure

Source

impl Readable for RTC_CALALR_SPEC

read() method returns rtc_calalr::R reader structure

Source

impl Readable for RTC_CALR_SPEC

read() method returns rtc_calr::R reader structure

Source

impl Readable for RTC_CR_SPEC

read() method returns rtc_cr::R reader structure

Source

impl Readable for RTC_IMR_SPEC

read() method returns rtc_imr::R reader structure

Source

impl Readable for RTC_MR_SPEC

read() method returns rtc_mr::R reader structure

Source

impl Readable for RTC_SR_SPEC

read() method returns rtc_sr::R reader structure

Source

impl Readable for RTC_TIMALR_SPEC

read() method returns rtc_timalr::R reader structure

Source

impl Readable for RTC_TIMR_SPEC

read() method returns rtc_timr::R reader structure

Source

impl Readable for RTC_VER_SPEC

read() method returns rtc_ver::R reader structure

Source

impl Readable for RTT_AR_SPEC

read() method returns rtt_ar::R reader structure

Source

impl Readable for RTT_MR_SPEC

read() method returns rtt_mr::R reader structure

Source

impl Readable for RTT_SR_SPEC

read() method returns rtt_sr::R reader structure

Source

impl Readable for RTT_VR_SPEC

read() method returns rtt_vr::R reader structure

Source

impl Readable for RVR_SPEC

read() method returns rvr::R reader structure

Source

impl Readable for SSC_CMR_SPEC

read() method returns ssc_cmr::R reader structure

Source

impl Readable for SSC_IMR_SPEC

read() method returns ssc_imr::R reader structure

Source

impl Readable for SSC_RC0R_SPEC

read() method returns ssc_rc0r::R reader structure

Source

impl Readable for SSC_RC1R_SPEC

read() method returns ssc_rc1r::R reader structure

Source

impl Readable for SSC_RCMR_SPEC

read() method returns ssc_rcmr::R reader structure

Source

impl Readable for SSC_RFMR_SPEC

read() method returns ssc_rfmr::R reader structure

Source

impl Readable for SSC_RHR_SPEC

read() method returns ssc_rhr::R reader structure

Source

impl Readable for SSC_RSHR_SPEC

read() method returns ssc_rshr::R reader structure

Source

impl Readable for SSC_SR_SPEC

read() method returns ssc_sr::R reader structure

Source

impl Readable for SSC_TCMR_SPEC

read() method returns ssc_tcmr::R reader structure

Source

impl Readable for SSC_TFMR_SPEC

read() method returns ssc_tfmr::R reader structure

Source

impl Readable for SSC_TSHR_SPEC

read() method returns ssc_tshr::R reader structure

Source

impl Readable for SSC_WPMR_SPEC

read() method returns ssc_wpmr::R reader structure

Source

impl Readable for SSC_WPSR_SPEC

read() method returns ssc_wpsr::R reader structure

Source

impl Readable for SUPC_MR_SPEC

read() method returns supc_mr::R reader structure

Source

impl Readable for SUPC_SMMR_SPEC

read() method returns supc_smmr::R reader structure

Source

impl Readable for SUPC_SR_SPEC

read() method returns supc_sr::R reader structure

Source

impl Readable for SUPC_WUIR_SPEC

read() method returns supc_wuir::R reader structure

Source

impl Readable for SUPC_WUMR_SPEC

read() method returns supc_wumr::R reader structure

Source

impl Readable for SYS_GPBR_SPEC

read() method returns sys_gpbr::R reader structure

Source

impl Readable for TC_BMR_SPEC

read() method returns tc_bmr::R reader structure

Source

impl Readable for TC_CMR_SPEC

read() method returns tc_cmr::R reader structure

Source

impl Readable for TC_CV_SPEC

read() method returns tc_cv::R reader structure

Source

impl Readable for TC_EMR_SPEC

read() method returns tc_emr::R reader structure

Source

impl Readable for TC_FMR_SPEC

read() method returns tc_fmr::R reader structure

Source

impl Readable for TC_IMR_SPEC

read() method returns tc_imr::R reader structure

Source

impl Readable for TC_QIMR_SPEC

read() method returns tc_qimr::R reader structure

Source

impl Readable for TC_QISR_SPEC

read() method returns tc_qisr::R reader structure

Source

impl Readable for TC_RAB_SPEC

read() method returns tc_rab::R reader structure

Source

impl Readable for TC_RA_SPEC

read() method returns tc_ra::R reader structure

Source

impl Readable for TC_RB_SPEC

read() method returns tc_rb::R reader structure

Source

impl Readable for TC_RC_SPEC

read() method returns tc_rc::R reader structure

Source

impl Readable for TC_SMMR_SPEC

read() method returns tc_smmr::R reader structure

Source

impl Readable for TC_SR_SPEC

read() method returns tc_sr::R reader structure

Source

impl Readable for TC_WPMR_SPEC

read() method returns tc_wpmr::R reader structure

Source

impl Readable for TRNG_IMR_SPEC

read() method returns trng_imr::R reader structure

Source

impl Readable for TRNG_ISR_SPEC

read() method returns trng_isr::R reader structure

Source

impl Readable for TRNG_ODATA_SPEC

read() method returns trng_odata::R reader structure

Source

impl Readable for TWIHS_CWGR_SPEC

read() method returns twihs_cwgr::R reader structure

Source

impl Readable for TWIHS_FILTR_SPEC

read() method returns twihs_filtr::R reader structure

Source

impl Readable for TWIHS_IADR_SPEC

read() method returns twihs_iadr::R reader structure

Source

impl Readable for TWIHS_IMR_SPEC

read() method returns twihs_imr::R reader structure

Source

impl Readable for TWIHS_MMR_SPEC

read() method returns twihs_mmr::R reader structure

Source

impl Readable for TWIHS_RHR_SPEC

read() method returns twihs_rhr::R reader structure

Source

impl Readable for TWIHS_SMBTR_SPEC

read() method returns twihs_smbtr::R reader structure

Source

impl Readable for TWIHS_SMR_SPEC

read() method returns twihs_smr::R reader structure

Source

impl Readable for TWIHS_SR_SPEC

read() method returns twihs_sr::R reader structure

Source

impl Readable for TWIHS_SWMR_SPEC

read() method returns twihs_swmr::R reader structure

Source

impl Readable for TWIHS_WPMR_SPEC

read() method returns twihs_wpmr::R reader structure

Source

impl Readable for TWIHS_WPSR_SPEC

read() method returns twihs_wpsr::R reader structure

Source

impl Readable for UART_BRGR_SPEC

read() method returns uart_brgr::R reader structure

Source

impl Readable for UART_CMPR_SPEC

read() method returns uart_cmpr::R reader structure

Source

impl Readable for UART_IMR_SPEC

read() method returns uart_imr::R reader structure

Source

impl Readable for UART_MR_SPEC

read() method returns uart_mr::R reader structure

Source

impl Readable for UART_RHR_SPEC

read() method returns uart_rhr::R reader structure

Source

impl Readable for UART_SR_SPEC

read() method returns uart_sr::R reader structure

Source

impl Readable for UART_WPMR_SPEC

read() method returns uart_wpmr::R reader structure

Source

impl Readable for USBHS_CTRL_SPEC

read() method returns usbhs_ctrl::R reader structure

Source

impl Readable for USBHS_DEVCTRL_SPEC

read() method returns usbhs_devctrl::R reader structure

Source

impl Readable for USBHS_DEVDMAADDRESS_SPEC

read() method returns usbhs_devdmaaddress::R reader structure

Source

impl Readable for USBHS_DEVDMACONTROL_SPEC

read() method returns usbhs_devdmacontrol::R reader structure

Source

impl Readable for USBHS_DEVDMANXTDSC_SPEC

read() method returns usbhs_devdmanxtdsc::R reader structure

Source

impl Readable for USBHS_DEVDMASTATUS_SPEC

read() method returns usbhs_devdmastatus::R reader structure

Source

impl Readable for USBHS_DEVEPTCFG_SPEC

read() method returns usbhs_deveptcfg::R reader structure

Source

impl Readable for USBHS_DEVEPTIMR_SPEC

read() method returns usbhs_deveptimr::R reader structure

Source

impl Readable for USBHS_DEVEPTISR_SPEC

read() method returns usbhs_deveptisr::R reader structure

Source

impl Readable for USBHS_DEVEPT_SPEC

read() method returns usbhs_devept::R reader structure

Source

impl Readable for USBHS_DEVFNUM_SPEC

read() method returns usbhs_devfnum::R reader structure

Source

impl Readable for USBHS_DEVIMR_SPEC

read() method returns usbhs_devimr::R reader structure

Source

impl Readable for USBHS_DEVISR_SPEC

read() method returns usbhs_devisr::R reader structure

Source

impl Readable for USBHS_HSTADDR1_SPEC

read() method returns usbhs_hstaddr1::R reader structure

Source

impl Readable for USBHS_HSTADDR2_SPEC

read() method returns usbhs_hstaddr2::R reader structure

Source

impl Readable for USBHS_HSTADDR3_SPEC

read() method returns usbhs_hstaddr3::R reader structure

Source

impl Readable for USBHS_HSTCTRL_SPEC

read() method returns usbhs_hstctrl::R reader structure

Source

impl Readable for USBHS_HSTDMAADDRESS_SPEC

read() method returns usbhs_hstdmaaddress::R reader structure

Source

impl Readable for USBHS_HSTDMACONTROL_SPEC

read() method returns usbhs_hstdmacontrol::R reader structure

Source

impl Readable for USBHS_HSTDMANXTDSC_SPEC

read() method returns usbhs_hstdmanxtdsc::R reader structure

Source

impl Readable for USBHS_HSTDMASTATUS_SPEC

read() method returns usbhs_hstdmastatus::R reader structure

Source

impl Readable for USBHS_HSTFNUM_SPEC

read() method returns usbhs_hstfnum::R reader structure

Source

impl Readable for USBHS_HSTIMR_SPEC

read() method returns usbhs_hstimr::R reader structure

Source

impl Readable for USBHS_HSTISR_SPEC

read() method returns usbhs_hstisr::R reader structure

Source

impl Readable for USBHS_HSTPIPCFG_SPEC

read() method returns usbhs_hstpipcfg::R reader structure

Source

impl Readable for USBHS_HSTPIPERR_SPEC

read() method returns usbhs_hstpiperr::R reader structure

Source

impl Readable for USBHS_HSTPIPIMR_SPEC

read() method returns usbhs_hstpipimr::R reader structure

Source

impl Readable for USBHS_HSTPIPINRQ_SPEC

read() method returns usbhs_hstpipinrq::R reader structure

Source

impl Readable for USBHS_HSTPIPISR_SPEC

read() method returns usbhs_hstpipisr::R reader structure

Source

impl Readable for USBHS_HSTPIP_SPEC

read() method returns usbhs_hstpip::R reader structure

Source

impl Readable for USBHS_SR_SPEC

read() method returns usbhs_sr::R reader structure

Source

impl Readable for US_BRGR_SPEC

read() method returns us_brgr::R reader structure

Source

impl Readable for US_CSR_SPEC

read() method returns us_csr::R reader structure

Source

impl Readable for US_FIDI_SPEC

read() method returns us_fidi::R reader structure

Source

impl Readable for US_ICDIFF_SPEC

read() method returns us_icdiff::R reader structure

Source

impl Readable for US_IDTRX_SPEC

read() method returns us_idtrx::R reader structure

Source

impl Readable for US_IDTTX_SPEC

read() method returns us_idttx::R reader structure

Source

impl Readable for US_IF_SPEC

read() method returns us_if::R reader structure

Source

impl Readable for US_IMR_SPEC

read() method returns us_imr::R reader structure

Source

impl Readable for US_LINBRR_SPEC

read() method returns us_linbrr::R reader structure

Source

impl Readable for US_LINIR_SPEC

read() method returns us_linir::R reader structure

Source

impl Readable for US_LINMR_SPEC

read() method returns us_linmr::R reader structure

Source

impl Readable for US_LONB1RX_SPEC

read() method returns us_lonb1rx::R reader structure

Source

impl Readable for US_LONB1TX_SPEC

read() method returns us_lonb1tx::R reader structure

Source

impl Readable for US_LONBL_SPEC

read() method returns us_lonbl::R reader structure

Source

impl Readable for US_LONDL_SPEC

read() method returns us_londl::R reader structure

Source

impl Readable for US_LONL2HDR_SPEC

read() method returns us_lonl2hdr::R reader structure

Source

impl Readable for US_LONMR_SPEC

read() method returns us_lonmr::R reader structure

Source

impl Readable for US_LONPRIO_SPEC

read() method returns us_lonprio::R reader structure

Source

impl Readable for US_LONPR_SPEC

read() method returns us_lonpr::R reader structure

Source

impl Readable for US_MAN_SPEC

read() method returns us_man::R reader structure

Source

impl Readable for US_MR_SPEC

read() method returns us_mr::R reader structure

Source

impl Readable for US_NER_SPEC

read() method returns us_ner::R reader structure

Source

impl Readable for US_RHR_SPEC

read() method returns us_rhr::R reader structure

Source

impl Readable for US_RTOR_SPEC

read() method returns us_rtor::R reader structure

Source

impl Readable for US_TTGR_SPEC

read() method returns us_ttgr::R reader structure

Source

impl Readable for US_WPMR_SPEC

read() method returns us_wpmr::R reader structure

Source

impl Readable for US_WPSR_SPEC

read() method returns us_wpsr::R reader structure

Source

impl Readable for UTMI_CKTRIM_SPEC

read() method returns utmi_cktrim::R reader structure

Source

impl Readable for UTMI_OHCIICR_SPEC

read() method returns utmi_ohciicr::R reader structure

Source

impl Readable for WDT_MR_SPEC

read() method returns wdt_mr::R reader structure

Source

impl Readable for WDT_SR_SPEC

read() method returns wdt_sr::R reader structure

Source

impl Readable for XDMAC_CBC_SPEC

read() method returns xdmac_cbc::R reader structure

Source

impl Readable for XDMAC_CC_SPEC

read() method returns xdmac_cc::R reader structure

Source

impl Readable for XDMAC_CDA_SPEC

read() method returns xdmac_cda::R reader structure

Source

impl Readable for XDMAC_CDS_MSP_SPEC

read() method returns xdmac_cds_msp::R reader structure

Source

impl Readable for XDMAC_CDUS_SPEC

read() method returns xdmac_cdus::R reader structure

Source

impl Readable for XDMAC_CIM_SPEC

read() method returns xdmac_cim::R reader structure

Source

impl Readable for XDMAC_CIS_SPEC

read() method returns xdmac_cis::R reader structure

Source

impl Readable for XDMAC_CNDA_SPEC

read() method returns xdmac_cnda::R reader structure

Source

impl Readable for XDMAC_CNDC_SPEC

read() method returns xdmac_cndc::R reader structure

Source

impl Readable for XDMAC_CSA_SPEC

read() method returns xdmac_csa::R reader structure

Source

impl Readable for XDMAC_CSUS_SPEC

read() method returns xdmac_csus::R reader structure

Source

impl Readable for XDMAC_CUBC_SPEC

read() method returns xdmac_cubc::R reader structure

Source

impl Readable for XDMAC_GCFG_SPEC

read() method returns xdmac_gcfg::R reader structure

Source

impl Readable for XDMAC_GIM_SPEC

read() method returns xdmac_gim::R reader structure

Source

impl Readable for XDMAC_GIS_SPEC

read() method returns xdmac_gis::R reader structure

Source

impl Readable for XDMAC_GRS_SPEC

read() method returns xdmac_grs::R reader structure

Source

impl Readable for XDMAC_GSWS_SPEC

read() method returns xdmac_gsws::R reader structure

Source

impl Readable for XDMAC_GS_SPEC

read() method returns xdmac_gs::R reader structure

Source

impl Readable for XDMAC_GTYPE_SPEC

read() method returns xdmac_gtype::R reader structure

Source

impl Readable for XDMAC_GWAC_SPEC

read() method returns xdmac_gwac::R reader structure

Source

impl Readable for XDMAC_GWS_SPEC

read() method returns xdmac_gws::R reader structure